/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome: REQUISICAO_CENTRAL

Descrio:
Clculo do Consumo Planejado (Cardpio, Consumo por Servio Fixo ou
Percapita) atravs da stored procedure CONSUMO_PLANEJADO e gravao na
tabela PREVRETI.

P_FILIAL       - Codigo da Filial
P_SERVICOS     - String contendo sequencia de Servios a serem calculados
P_DTINICIAL    - Data inicial
P_DTFINAL      - Data final
P_IDARQUIVO    - Identificador da tabela a ser gravada
                 "P" -> PREVRETI
                 "C" -> CONSPLAN
                 "A" -> AMBAS
P_IDPRODUTOS   - Identificador dos produtos a serem gravados.
                 Formato "XXX"
                 1 posio = "C" -> Cardpio
                 2 posio = "F" -> Consumo por Servio Fixo
                 3 posio = "P" -> Consumo por Servio Percapita
P_IDSEPPRATO   - Identificador de requisio analtica, ou seja, separada
                 por prato ou por setor, consumo fixo e consumo percapita.
                 Formato "S" (setor), "P" (prato) ou "N" (n/a).
P_PEACRESCIMO  - Percentual de acrscimo
P_IDARREDOND   - Identificador de utilizao do arredondamento
                 para requisio do Produto. Formato "S" ou "N"
P_NRCONSPLAN   - Nmero sequencial a ser utilizado para gravao dos dados
P_CDPRODUTOINI - Cdigo do Produto inicial
P_CDPRODUTOFIN - Cdigo do Produto final
P_CDOPERADOR   - Cdigo do Operador
P_DTHRCALCPR   - Data/hora do clculo
P_STDTINICIAL  - Lista de data inicial em string por servio
P_STDTFINAL    - Lista de data final em string por servio

Para aplicar e debugar
-- @H:\SISTEMAS\DBA\SQL\ORACLE\7120_PLASTP_REQUISICAO_ANALITICA_SETOR_PLA.SQL
-- SET SERVEROUTPUT ON
-- DBMS_OUTPUT.PUT_LINE('xx');

Criao:
01/03/99 - Ederson

*/

CREATE OR REPLACE
PROCEDURE REQUISICAO_CENTRAL
  (P_CDCENTRAL    IN VARCHAR2,
   P_CDFILAGREG   IN VARCHAR2,
   P_SERVICOS     IN CLOB,
   P_DTINICIAL    IN DATE,
   P_DTFINAL      IN DATE,
   P_IDARQUIVO    IN VARCHAR2,
   P_IDPRODUTOS   IN VARCHAR2,
   P_IDSEPPRATO   IN VARCHAR2,
   P_PEACRESCIMO  IN NUMBER,
   P_IDARREDOND   IN VARCHAR2,
   P_NRCONSPLAN   IN VARCHAR2,
   P_CDPRODUTOINI IN VARCHAR2,
   P_CDPRODUTOFIN IN VARCHAR2,
   P_CDOPERADOR   IN VARCHAR2,
   P_DTHRCALCPR   IN DATE,
   P_STDTINICIAL  IN VARCHAR2 DEFAULT NULL,
   P_STDTFINAL    IN VARCHAR2 DEFAULT NULL) IS

   V_CDSERVFILI    CLOB;
   V_CDSERVFILIAUX VARCHAR2(4000);
   V_CDPRODUTOFIN  VARCHAR2(10);
   V_CDFILIAL      VARCHAR(4);

BEGIN
   V_CDPRODUTOFIN := RPAD(P_CDPRODUTOFIN,10,'z');

   FOR C_FILIAL IN(
      SELECT CDFILIAL
      FROM FILIAL
      WHERE (CDFILCENTPME = P_CDCENTRAL)
        AND ((INSTR(P_CDFILAGREG, CDFILIAL) > 0) OR P_CDFILAGREG = 'T')
   )LOOP

      V_CDSERVFILI := '_';
      FOR C_SERVICO IN (
         SELECT CDSERVFILI
         FROM SERVICO
         WHERE CDFILIAL = C_FILIAL.CDFILIAL
          AND (INSTR(P_SERVICOS, '_'||CDFILIAL||CDSERVFILI||'_') > 0)
      ) LOOP

        V_CDSERVFILI := V_CDSERVFILI || C_SERVICO.CDSERVFILI || '_';

      END LOOP;

      CONSUMO_PLANEJADO_PLA(C_FILIAL.CDFILIAL,
                            V_CDSERVFILI,
                            P_DTINICIAL,
                            P_DTFINAL,
                            P_IDARQUIVO,
                            P_IDPRODUTOS,
                            P_IDSEPPRATO,
                            P_PEACRESCIMO,
                            P_IDARREDOND,
                            P_NRCONSPLAN,
                            P_CDPRODUTOINI,
                            V_CDPRODUTOFIN,
                            P_CDOPERADOR,
                            P_STDTINICIAL,
                            P_STDTFINAL);

   END LOOP;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('REQUISICAO_CENTRAL','0.00.000'); END;
/